@@ -24,7 +24,6 @@ from datetime import datetime as dt
 import pandas
 
 from grimoirelab_toolkit.datetime import str_to_datetime
-from grimoire_elk.enriched.sortinghat_gelk import SortingHat
 
 
 class Events(object):
@@ -97,14 +96,7 @@ class Events(object):
         df_columns[Events.PROJECT].append(project_item[Events.PROJECT])
         df_columns[Events.PROJECT_1].append(project_item[Events.PROJECT_1])
 
-    def _add_sh_info(self, df_columns, item, update_sh_db=False):
-
-        # To ensure we have procesed the entity
-        if update_sh_db:
-            identities = self.enrich.get_identities(item)
-            SortingHat.add_identities(self.enrich.sh_db, identities,
-                                      self.enrich.get_connector_name())
-
+    def _add_sh_info(self, df_columns, item):
         # Add the grimoire_creation_date to the raw item
         # It is used for getting the right affiliation
         item.update(self.enrich.get_grimoire_fields(
@@ -390,9 +382,11 @@ class Git(Events):
     COMMIT_ID = "id"
     COMMIT_EVENT = "eventtype"
     COMMIT_DATE = "date"
+    COMMIT_TZ = "tz"
     COMMIT_OWNER = "owner"
     COMMIT_COMMITTER = "committer"
     COMMIT_COMMITTER_DATE = "committer_date"
+    COMMIT_COMMITTER_TZ = "committer_tz"
     COMMIT_REPOSITORY = "repository"
     COMMIT_MESSAGE = "message"
     COMMIT_NUM_FILES = "num_files"
@@ -426,15 +420,27 @@ class Git(Events):
         repository = item["origin"]
 
         creation_date = str_to_datetime(commit_data['AuthorDate'])
+        try:
+            creation_date_tz = int(creation_date.strftime("%z")[0:3])
+        except ValueError:
+            creation_date_tz = 0
+
+        committer_date = str_to_datetime(commit_data['CommitDate'])
+        try:
+            committer_date_tz = int(committer_date.strftime("%z")[0:3])
+        except ValueError:
+            committer_date_tz = 0
 
         df_columns[Git.COMMIT_HASH].append(commit_data['commit'])
 
         df_columns[Git.COMMIT_ID].append(commit_data['commit'])
         df_columns[Git.COMMIT_EVENT].append(Git.EVENT_COMMIT)
         df_columns[Git.COMMIT_DATE].append(creation_date)
+        df_columns[Git.COMMIT_TZ].append(creation_date_tz)
         df_columns[Git.COMMIT_OWNER].append(commit_data['Author'])
         df_columns[Git.COMMIT_COMMITTER].append(commit_data['Commit'])
-        df_columns[Git.COMMIT_COMMITTER_DATE].append(str_to_datetime(commit_data['CommitDate']))
+        df_columns[Git.COMMIT_COMMITTER_DATE].append(committer_date)
+        df_columns[Git.COMMIT_COMMITTER_TZ].append(committer_date_tz)
         df_columns[Git.COMMIT_REPOSITORY].append(repository)
         if 'message' in commit_data.keys():
             df_columns[Git.COMMIT_MESSAGE].append(commit_data['message'])
@@ -468,9 +474,11 @@ class Git(Events):
         df_columns[Git.COMMIT_ID] = []
         df_columns[Git.COMMIT_EVENT] = []
         df_columns[Git.COMMIT_DATE] = []
+        df_columns[Git.COMMIT_TZ] = []
         df_columns[Git.COMMIT_OWNER] = []
         df_columns[Git.COMMIT_COMMITTER] = []
         df_columns[Git.COMMIT_COMMITTER_DATE] = []
+        df_columns[Git.COMMIT_COMMITTER_TZ] = []
         df_columns[Git.COMMIT_REPOSITORY] = []
         df_columns[Git.COMMIT_MESSAGE] = []
         df_columns[Git.COMMIT_NUM_FILES] = []
@@ -561,9 +569,11 @@ class Git(Events):
         events[Git.COMMIT_ID] = df_columns[Git.COMMIT_ID]
         events[Git.COMMIT_EVENT] = df_columns[Git.COMMIT_EVENT]
         events[Git.COMMIT_DATE] = df_columns[Git.COMMIT_DATE]
+        events[Git.COMMIT_TZ] = df_columns[Git.COMMIT_TZ]
         events[Git.COMMIT_OWNER] = df_columns[Git.COMMIT_OWNER]
         events[Git.COMMIT_COMMITTER] = df_columns[Git.COMMIT_COMMITTER]
         events[Git.COMMIT_COMMITTER_DATE] = df_columns[Git.COMMIT_COMMITTER_DATE]
+        events[Git.COMMIT_COMMITTER_TZ] = df_columns[Git.COMMIT_COMMITTER_TZ]
         events[Git.COMMIT_REPOSITORY] = df_columns[Git.COMMIT_REPOSITORY]
         events[Git.COMMIT_MESSAGE] = df_columns[Git.COMMIT_MESSAGE]
         events[Git.COMMIT_HASH] = df_columns[Git.COMMIT_HASH]
